@@ -67,7 +67,7 @@ def _get_cache_dir(custom_cache_dir: Path | None, *, use_pip: bool = True) -> Pa
             return pip_cache_dir
         else:
             logger.warning(
-                f"Warning: pip {_PIP_VERSION} doesn't support the `cache dir` subcommand, "
+                f"pip {_PIP_VERSION} doesn't support the `cache dir` subcommand, "
                 f"using {_PIP_AUDIT_INTERNAL_CACHE} instead"
             )
             return _PIP_AUDIT_INTERNAL_CACHE
@@ -113,7 +113,7 @@ class _SafeFileCache(FileCache):
         # Make sure the directory exists
         try:
             os.makedirs(os.path.dirname(name), self.dirmode)
-        except (IOError, OSError):  # pragma: no cover
+        except OSError:  # pragma: no cover
             pass
 
         # We don't want to use lock files since `pip` isn't going to recognise those. We should
