@@ -8,7 +8,7 @@ import json
 import logging
 import venv
 from types import SimpleNamespace
-from typing import Iterator, Tuple
+from typing import Iterator
 
 from packaging.version import Version
 
@@ -54,7 +54,7 @@ class VirtualEnv(venv.EnvBuilder):
         """
         super().__init__(with_pip=True)
         self._install_args = install_args
-        self._packages: list[Tuple[str, Version]] | None = None
+        self._packages: list[tuple[str, Version]] | None = None
         self._state = state
 
     def post_setup(self, context: SimpleNamespace) -> None:
@@ -78,6 +78,8 @@ class VirtualEnv(venv.EnvBuilder):
 
         # Firstly, upgrade our `pip` versions since `ensurepip` can leave us with an old version
         # and install `wheel` in case our package dependencies are offered as wheels
+        # TODO: This is probably replaceable with the `upgrade_deps` option on `EnvBuilder`
+        # itself, starting with Python 3.9.
         pip_upgrade_cmd = [
             context.env_exe,
             "-m",
@@ -86,6 +88,7 @@ class VirtualEnv(venv.EnvBuilder):
             "--upgrade",
             "pip",
             "wheel",
+            "setuptools",
         ]
         try:
             run(pip_upgrade_cmd, state=self._state)
@@ -124,7 +127,7 @@ class VirtualEnv(venv.EnvBuilder):
             self._packages.append((package["name"], Version(package["version"])))
 
     @property
-    def installed_packages(self) -> Iterator[Tuple[str, Version]]:
+    def installed_packages(self) -> Iterator[tuple[str, Version]]:
         """
         A property to inspect the list of packages installed in the virtual environment.
 
